export * from './types.js';
import { XmlSaxParserElemHandler, XmlSaxParserOptions, XmlSaxParserValueHandler } from './types.js';
export declare class XmlSaxParser {
    #private;
    options: XmlSaxParserOptions;
    delimiter: string;
    constructor(options?: XmlSaxParserOptions);
    isStopped(): boolean;
    /**
     * Add element handler
     *
     * ```js
     * parser.onElem((elPath, level) => {
     *   // ...
     * })
     * ```
     */
    onElem(handler: XmlSaxParserElemHandler): this;
    /**
     * Remove element handler
     */
    offElem(handler: XmlSaxParserElemHandler): this;
    /**
     * Add element value handler
     *
     * ```js
     * parser.onValue((elPath, val, level) => {
     *   // ...
     * })
     * ```
     */
    onValue(handler: XmlSaxParserValueHandler): this;
    /**
     * Remove element value handler
     */
    offValue(handler: XmlSaxParserValueHandler): this;
    /**
     * Start XML source parsing
     */
    start(): Promise<void>;
    /**
     * Write chunk of xml to parse
     *
     * @param chunk Xml content chunk
     */
    write(chunk: Uint8Array): void;
    /** Stop xml parsing */
    stop(): void;
}
